##  Subscribing to Fact Sheets
As an admin or member, you can subscribe to a fact sheet or add new subscribers to fact sheets. To subscribe to a fact sheet, do the following:
  1. In the fact sheet, go to the Subscriptions tab.
  2. Click on the + Add a person button. This opens an overlay where you can enter the subscriber’s details.
  3. Search for and enter the subscriber's email, then choose the appropriate subscription type and role.
     * You will see only roles that match the selected subscription type. If a subscription role has been created as type All, it will be available for any of the 3 subscription types. To learn more, see [Creating a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af3a27a4410148eada5eb5d54814b__creating_a_subscription_role).
     * Providing a subscription role is optional by default, but admins can also make it mandatory in the settings. To learn more, see [Enforcing Mandatory Selection of a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af3a27a4410148eada5eb5d54814b__enforcing_mandatory_selection_of_a_subscription_role).
     * You can also assign multiple subscription roles to the same user. To assign multiple roles for the same user, click the Add Role button and include the respective roles.
  4. Click Save to finish subscribing.


You can also subscribe to multiple fact sheets at once. To learn how to do it, see [Subscribing and Unsubscribing in Bulk](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a16427a441014be448690c54e7cf0__subscribing_and_unsubscribing_in_bulk).
